@@ -17,13 +17,13 @@
  *
  * Authors:   Carsten Lucke <luckec@tool-garage.de>
  *
- * CVS file id: $Id: Driver.php 277674 2009-03-24 00:31:24Z kguest $
+ * CVS file id: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
  *
  * @category Date
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 277674 2009-03-24 00:31:24Z kguest $
+ * @version  CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -35,7 +35,7 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 277674 2009-03-24 00:31:24Z kguest $
+ * @version  CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -119,7 +119,7 @@ define('DATE_HOLIDAYS_DRIVER_IDENTIFY_ISO3166_METHOD', 'getISO3166Codes');
  * @subpackage Driver
  * @author     Carsten Lucke <luckec@tool-garage.de>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: Driver.php 277674 2009-03-24 00:31:24Z kguest $
+ * @version    CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
  * @link       http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver
@@ -301,7 +301,7 @@ class Date_Holidays_Driver
      */
     function addTranslation($locale)
     {
-        $data_dir = "/usr/obj/ports/pear-Date-Holidays-0.21.4/fake-alpha/var/www/pear/data";
+        $data_dir = "/usr/obj/pear-Date-Holidays-0.21.5/fake-i386/var/www/pear/data";
         $bestLocale = $this->_findBestLocale($locale);
         $matches = array();
         $loaded = false;
@@ -1277,6 +1277,7 @@ class Date_Holidays_Driver
      */
     function _calcFirstMonday($month)
     {
+        $month = sprintf("%02d", $month);
         $date = new Date($this->_year . "-$month-01");
         while ($date->getDayOfWeek() != 1) {
             $date = $date->getNextDay();
@@ -1294,10 +1295,13 @@ class Date_Holidays_Driver
     function _calcLastMonday($month)
     {
         //work backwards from the first day of the next month.
+        $month = sprintf("%02d", $month);
         $nm = ((int) $month ) + 1;
         if ($nm > 12) {
             $nm = 1;
         }
+        $nm = sprintf("%02d", $nm);
+
         $date = new Date($this->_year . "-$nm-01");
         $date = $date->getPrevDay();
         while ($date->getDayOfWeek() != 1) {
@@ -1389,6 +1393,11 @@ class Date_Holidays_Driver
                                                                 $date->year) +
                                           $pn_days,
                                           '%Y %m %d'));
+        if (isset($new_date->on_standardyear)) {
+            $new_date->on_standardyear = $new_date->year;
+            $new_date->on_standardmonth = $new_date->month;
+            $new_date->on_standardday = $new_date->day;
+        }
         return $new_date;
     }
 
